@@ -130,8 +130,13 @@ class MinioClient(BaseClient):
         file: UploadFile,
         bucket_name: str,
         parent_path: str = "",
+        timeout: int = 60
     ) -> File:
 
+        # Passing timeout as function argument to as baseclient accepts it for gcp.
+        # This parameter will not affect function execution for minio.
+        LOG.info("Minio put_object currently does not support setting timeout to: {}", timeout)
+        
         if parent_path != "":
             parent_path += "/"
         try:
