@@ -26,14 +26,14 @@ def setup_storage(app: FastAPI) -> None:
             secure=settings.MINIO_SSL,
         )
         app.minio = minioClient  # type: ignore
-    elif (
-        settings.STORAGE_TYPE == StorageType.GCP_STORAGE
-        or settings.STORAGE_TYPE == StorageType.FIREBASE_STORAGE
-    ):
-        from google.cloud import storage
+    elif settings.STORAGE_TYPE in [
+        StorageType.GCP_STORAGE,
+        StorageType.FIREBASE_STORAGE,
+    ]:
+        from google.cloud.storage import Client as GCPClient
 
         # Uses GOOGLE_APPLICATION_CREDENTIALS Env Var
-        gcp_storage_client = storage.Client()
+        gcp_storage_client = GCPClient()
         app.gcp_storage = gcp_storage_client  # type: ignore
     elif settings == StorageType.NONE:
         logger.info("Storage set to NONE and cannot be used")
